Documentation
¶
Index ¶
- type HardwareInfo
- type NetworkInfo
- type Via
- func (v *Via) GetHardwareInfo(ctx context.Context) (HardwareInfo, error)
- func (v *Via) Healthy(ctx context.Context) error
- func (v *Via) Info(ctx context.Context) (interface{}, error)
- func (v *Via) SetVolume(ctx context.Context, block string, volume int) error
- func (v *Via) Volumes(ctx context.Context, block []string) (map[string]int, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type HardwareInfo ¶
type HardwareInfo struct {
Hostname string `json:"hostname,omitempty"`
ModelName string `json:"model_name,omitempty"`
SerialNumber string `json:"serial_number,omitempty"`
BuildDate string `json:"build_date,omitempty"`
FirmwareVersion string `json:"firmware_version,omitempty"`
ProtocolVersion string `json:"protocol_version,omitempty"`
NetworkInfo NetworkInfo `json:"network_information,omitempty"`
FilterStatus string `json:"filter_status,omitempty"`
WarningStatus []string `json:"warning_status,omitempty"`
ErrorStatus []string `json:"error_status,omitempty"`
PowerStatus string `json:"power_status,omitempty"`
PowerSavingModeStatus string `json:"power_saving_mode_status,omitempty"`
TimerInfo []map[string]int `json:"timer_info,omitempty"`
Temperature string `json:"temperature,omitempty"`
}
HardwareInfo contains the common information for device hardware information
type NetworkInfo ¶
type NetworkInfo struct {
IPAddress string `json:"ip_address,omitempty"`
MACAddress string `json:"mac_address,omitempty"`
Gateway string `json:"gateway,omitempty"`
DNS []string `json:"dns,omitempty"`
}
NetworkInfo contains the network information for the device
type Via ¶
VIA Struct that defines general parameters needed for any VIA
func (*Via) GetHardwareInfo ¶
func (v *Via) GetHardwareInfo(ctx context.Context) (HardwareInfo, error)
Click to show internal directories.
Click to hide internal directories.